@@ -1,4 +1,5 @@
-@defaults = ( [  2, 2 ], 1, 1, 7, 0.01, 0.99 )
+@defaults = ( [  2, 2 ], 1, 1, 7, 0.01, 0.99 );
+
 
 
 ### The above line means: ( [ resolution_x, resolution_y ], $dirvectorsnum, $bounceambnum, $bouncemaxnum, $distgrid, $threshold )
@@ -20,3 +21,17 @@
 # A value of "1" means that if the new shading value is increased instead of decreased in place of the old one,
 # the change is not executed.
 
+$computype = "linear";
+# TYPES OF CALCULATIONS FOR CALCULATING THE IRRADIANCE FACTORS.
+# (SEE SUBROUTINE "compareirrs".)
+# OPTIONS: "linear", "quadratic", "root".
+# THESE OPTIONS ARE ON THE WAY TO BE DISCARDED AND BECOME OBSOLETE.
+# WHEN ABSENT, THEY DEFAULT TO "linear".
+
+$calcprocedure = "complete";
+# THESE CALCULATION OPTIONS REGARD THE IRRADIANCES. THEY ARE: "complete" AND "simplified".
+# (SEE SUBROUTINE "pursue").
+# WITH THE "complete" option, both $bounceambnum and $bouncemaxnum must be assigned a value higher than 0.
+# WHEN ABSENT, THEY DEFAULT TO "SIMPLIFIED".
+
+
